==> openjdk-lts_10.0.1+10.orig.tar.xz: openjdk-10-10.0.1+10/test/langtools/jdk/javadoc/doclet/testModules/TestEmptyModule.java <==
/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8193107
 * @summary test an empty module
 * @modules jdk.javadoc/jdk.javadoc.internal.api
 *          jdk.javadoc/jdk.javadoc.internal.tool
 *          jdk.compiler/com.sun.tools.javac.api
 *          jdk.compiler/com.sun.tools.javac.main
 * @library ../lib /tools/lib
 * @build toolbox.ToolBox toolbox.ModuleBuilder JavadocTester
 * @run main TestEmptyModule
 */

import toolbox.ModuleBuilder;
import toolbox.ToolBox;

import java.nio.file.Path;
import java.nio.file.Paths;

public class TestEmptyModule extends JavadocTester {

    public final ToolBox tb;
    public static void main(String... args) throws Exception {
        TestEmptyModule tester = new TestEmptyModule();
        tester.runTests(m -> new Object[] { Paths.get(m.getName()) });
    }

    public TestEmptyModule() {
        tb = new ToolBox();
    }

    @Test
    public void checkEmptyModule(Path base) throws Exception {
        ModuleBuilder mb = new ModuleBuilder(tb, "empty")
                .comment("module empty.");
                mb.write(base);

        javadoc("-d", base.resolve("out").toString(),
                "-quiet",
                "--module-source-path", base.toString(),
                "--module", "empty");
        checkExit(Exit.OK);

        checkOutput("empty-summary.html", true,
                "module empty.");
    }

}

==> openjdk-lts_11.0.29+7.orig.tar.xz: openjdk-11-11.0.29+7/test/langtools/jdk/javadoc/doclet/testModules/TestEmptyModule.java <==
/*
 * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8193107
 * @summary test an empty module
 * @modules jdk.javadoc/jdk.javadoc.internal.api
 *          jdk.javadoc/jdk.javadoc.internal.tool
 *          jdk.compiler/com.sun.tools.javac.api
 *          jdk.compiler/com.sun.tools.javac.main
 * @library ../lib /tools/lib
 * @build toolbox.ToolBox toolbox.ModuleBuilder JavadocTester
 * @run main TestEmptyModule
 */

import toolbox.ModuleBuilder;
import toolbox.ToolBox;

import java.nio.file.Path;
import java.nio.file.Paths;

public class TestEmptyModule extends JavadocTester {

    public final ToolBox tb;
    public static void main(String... args) throws Exception {
        TestEmptyModule tester = new TestEmptyModule();
        tester.runTests(m -> new Object[] { Paths.get(m.getName()) });
    }

    public TestEmptyModule() {
        tb = new ToolBox();
    }

    @Test
    public void checkEmptyModule(Path base) throws Exception {
        ModuleBuilder mb = new ModuleBuilder(tb, "empty")
                .comment("module empty.");
                mb.write(base);

        javadoc("-d", base.resolve("out").toString(),
                "-quiet",
                "--module-source-path", base.toString(),
                "--module", "empty");
        checkExit(Exit.OK);

        checkOutput("empty/module-summary.html", true,
                "module empty.");
    }

}
